@@ -307,14 +307,12 @@ function getCredentialsObject($user, $password) {
 function getContextObject($context_id){
 	$ctx = new Context();
 	$ctx->id = $context_id;
-	$ctx->idset = true;
 	return $ctx;
 }
 
 function getUserObject($user_id){
 	$usr = new User();
 	$usr->id = $user_id;
-	$usr->idset = true;
 	return $usr;
 }
 
